@@ -1,4 +1,4 @@
-// Copyright (C) 2011 Ben Asselstine
+// Copyright (C) 2011, 2014 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -36,11 +36,16 @@ class CBCShowList: public std::list<CBCShow>
         
         bool contains(Glib::ustring id);
         //statics
-        static CBCShowList* create_from_json(const char *data, int datalen);
+        static CBCShowList* create_from_html(const char *data, int datalen);
         
     protected:
         CBCShowList(const char *data, int datalen);
     private:
+        Glib::ustring get_id(Glib::ustring data);
+        Glib::ustring get_title(Glib::ustring data);
+        Glib::ustring get_desc(Glib::ustring data);
+        Glib::ustring get_span(Glib::ustring data, Glib::ustring span);
+        bool get_live(Glib::ustring data);
 
 };
 
