@@ -1,4 +1,4 @@
-//  Copyright (C) 2011 Ben Asselstine
+//  Copyright (C) 2011, 2014 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -16,24 +16,17 @@
 //  02110-1301, USA.
 
 #include "cbc-show.h"
-CBCShow::CBCShow(Glib::ustring id, Glib::ustring title, time_t point, guint duration)
-  :d_id(id), d_title(title), d_air(point, point + duration)
+CBCShow::CBCShow(Glib::ustring id, Glib::ustring title, Glib::ustring desc,
+                 bool live)
+  :d_id(id), d_title(title), d_desc(desc), d_live(live)
 {
 }
 
 CBCShow::CBCShow(const CBCShow& t)
-  :d_id(t.d_id), d_title(t.d_title), d_air(t.d_air)
+  :d_id(t.d_id), d_title(t.d_title), d_desc(t.d_desc), d_live(t.d_live)
 {
 }
 
 CBCShow::~CBCShow()
 {
 }
-
-bool CBCShow::is_showing()
-{
-  EventDate now;
-  //printf("date is: %s, duration is %lf\n", d_air.to_string(true).c_str(),
-         //d_air.get_duration());
-  return d_air.straddles(now);
-}
