@@ -1,4 +1,4 @@
-//  Copyright (C) 2011 Ben Asselstine
+//  Copyright (C) 2011, 2014 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -18,28 +18,27 @@
 #ifndef CBC_SHOW_H 
 #define CBC_SHOW_H
 #include <gtkmm.h>
-#include "event-date-region.h"
 class CBCShow
 {
     public:
 
-        CBCShow(Glib::ustring id, Glib::ustring title, time_t point, guint duration);
+        CBCShow(Glib::ustring id, Glib::ustring title, Glib::ustring desc, bool live);
 
         CBCShow(const CBCShow& t);
 
-        bool is_showing();
-
-        Glib::ustring get_id() const {return d_id;};
-        Glib::ustring get_title() const {return d_title;};
+        Glib::ustring get_id() const { return d_id; }
+        Glib::ustring get_title() const { return d_title; }
+        Glib::ustring get_description() const { return d_desc; }
 	//! Destructor.
         ~CBCShow();
 
+        bool is_showing() const { return d_live; }
     protected:
     private:
         Glib::ustring d_id;
         Glib::ustring d_title;
-        EventDateRegion d_air;
-
+        Glib::ustring d_desc;
+        bool d_live;
 };
 
 #endif // CBC_SHOW_H
